CLI Config API
==============

.. toctree::
   :maxdepth: 4

   cliconfig.processing

cliconfig.config\_routines
--------------------------

.. automodule:: cliconfig.config_routines
   :members:
   :undoc-members:
   :show-inheritance:

cliconfig.cli\_parser
---------------------

.. automodule:: cliconfig.cli_parser
   :members:
   :undoc-members:
   :show-inheritance:

cliconfig.dict\_routines
------------------------

.. automodule:: cliconfig.dict_routines
   :members:
   :undoc-members:
   :show-inheritance:

cliconfig.process\_routines
---------------------------

.. automodule:: cliconfig.process_routines
   :members:
   :undoc-members:
   :show-inheritance:

cliconfig.tag\_routines
-----------------------

.. automodule:: cliconfig.tag_routines
   :members:
   :undoc-members:
   :show-inheritance:
